@@ -1,6 +1,6 @@
 package Map::Tube::London;
 
-$Map::Tube::London::VERSION = '0.03';
+$Map::Tube::London::VERSION = '0.04';
 
 use 5.006;
 use Data::Dumper;
@@ -8,7 +8,7 @@ use Data::Dumper;
 use Moo;
 use namespace::clean;
 
-has xml => (is => 'ro', default => 'london-map.xml');
+has xml => (is => 'ro', default => sub { return 'london-map.xml' });
 
 with 'Map::Tube';
 
@@ -18,7 +18,7 @@ Map::Tube::London - Interface to the London Tube Map.
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =head1 DESCRIPTION
 
